# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/eddb/81_navroute.ipynb.

# %% auto 0
__all__ = ['navigationroute']

# %% ../../nbs/eddb/81_navroute.ipynb 3
import os
import json

from logging import getLogger


# %% ../../nbs/eddb/81_navroute.ipynb 4
syslog = getLogger(f"root.{__name__}")
default_journaling_path = os.path.join(os.getenv("userprofile"), "Saved Games", "Elite Dangerous")

# %% ../../nbs/eddb/81_navroute.ipynb 5
def navigationroute(journalingpath:str=None):
    '''
        Iter over Navigation Route files

        Args:
            journalingpath (str): Path to directory with Elite Dangerous logfiles
    
    '''

    try:
        navfile = os.path.join(
            default_journaling_path if journalingpath is None else journalingpath, 
            "NavRoute.json"
        )

        syslog.debug("Reading Navigation Route from %s" % navfile)

        with open(navfile, "rt") as jsonfile:
            for item in json.load(jsonfile).get('Route'):
                yield item

    except KeyboardInterrupt as kbi:
        syslog.exception("Keyboard Interrupt", exc_info=True)
        




# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/EDTravelCompanion',
                'doc_host': 'https://fenke.github.io',
                'git_url': 'https://github.com/fenke/EDTravelCompanion',
                'lib_path': 'edcompanion'},
  'syms': { 'edcompanion.core': {'edcompanion.core.foo': ('core.html#foo', 'edcompanion/core.py')},
            'edcompanion.eddb.navigation': { 'edcompanion.eddb.navigation.navigationroute': ( 'eddb/navroute.html#navigationroute',
                                                                                              'edcompanion/eddb/navigation.py')},
            'edcompanion.linalg.fitsvd': { 'edcompanion.linalg.fitsvd.fitline': ( 'linalg/linalg_fitsvd.html#fitline',
                                                                                  'edcompanion/linalg/fitsvd.py')},
            'edcompanion.md.edastro': { 'edcompanion.md.edastro.create_galaxymap_url': ( 'md/edastro.html#create_galaxymap_url',
                                                                                         'edcompanion/md/edastro.py'),
                                        'edcompanion.md.edastro.embed_galaxymap': ( 'md/edastro.html#embed_galaxymap',
                                                                                    'edcompanion/md/edastro.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/md/90_edastro.ipynb.

# %% auto 0
__all__ = ['github_raw_base_url', 'ed_astro_galmap_url', 'create_galaxymap_url', 'embed_galaxymap']

# %% ../../nbs/md/90_edastro.ipynb 3
#| export


# %% ../../nbs/md/90_edastro.ipynb 4
github_raw_base_url = "https://raw.githubusercontent.com/fenke/EDTravelCompanion/main/nbs/blog/posts/ed-guardians-1/"
ed_astro_galmap_url="https://edastro.com/galmap/"

def create_galaxymap_url(markers, **kwargs):

    if kwargs:
        ed_astro_galmap_custom_url = f"{ed_astro_galmap_url}?{'&'.join([f'{k}={v}' for k,v in kwargs.items()])}&custom="
    else:
        ed_astro_galmap_custom_url = f"{ed_astro_galmap_url}?custom="

    if isinstance(markers, list):
        source = f"{ed_astro_galmap_custom_url}{';'.join([github_raw_base_url + str(s) for s in markers])}"
    else:
        source = f"{ed_astro_galmap_custom_url}{github_raw_base_url + str(markers)}"

    return source 


# %% ../../nbs/md/90_edastro.ipynb 5
def embed_galaxymap(markers, **kwargs):
    return f''' <iframe width=100% height=800 src="{create_galaxymap_url(markers, **kwargs)}"></iframe> '''




# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/linalg/10_linalg_fitsvd.ipynb.

# %% auto 0
__all__ = ['fitline']

# %% ../../nbs/linalg/10_linalg_fitsvd.ipynb 11
import numpy as np

# %% ../../nbs/linalg/10_linalg_fitsvd.ipynb 12
def fitline(points): 
    
    # center the data points by subtracting the mean to 
    # remove the bias (intercept)
    avg = np.mean(points, axis=0)
    subtracted = points - avg
    
    _, _, V = np.linalg.svd(subtracted)

    # the direction vector is the right singular vector 
    # corresponding to the largest singular value
    direction = V[0, :]
    
    # A line is defined by a support vector, the average,
    # and its direction
    p0 = avg
    d = direction

    return p0, d


